netapp_ontap.models.snapshot_policy_copies API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapshot_policy_copies`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapshotPolicyCopiesSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapshotPolicyCopies object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `count GET POST PATCH`

    The number of Snapshot copies to maintain for this schedule.

  `prefix GET POST PATCH`

    The prefix to use while creating Snapshot copies at regular intervals.

  `schedule GET POST PATCH`

    The schedule field of the snapshot_policy_copies.

  `snapmirror_label GET POST PATCH`

    Label for SnapMirror operations